==> pan-0.13.2.tar.bz2: pan-0.13.2/pan/save-ui.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*********************
**********************  Includes
*********************/

#include <config.h>

#include <string.h>

#include <glib.h>
#include <gtk/gtk.h>

#include <pan/base/base-prefs.h>
#include <pan/base/debug.h>
#include <pan/base/log.h>
#include <pan/base/pan-i18n.h>
#include <pan/base/pan-glib-extensions.h>

#include <pan/globals.h>
#include <pan/gui.h>
#include <pan/prefs.h>
#include <pan/queue.h>
#include <pan/pan-file-entry.h>
#include <pan/task-bodies.h>
#include <pan/task-save.h>
#include <pan/save-ui.h>
#include <pan/text.h>
#include <pan/util.h>

/*********************
**********************  Private Function Prototypes
*********************/

static gchar * _path = NULL;
static gboolean _high_priority = FALSE;
static gboolean _save_attachments = TRUE;
static gboolean _save_text = FALSE;

/*********************
**********************  BEGINNING OF SOURCE
*********************/

typedef struct
{
	GtkWidget * dialog;

	GtkWidget * save_text_check;
	GtkWidget * save_attachments_check;
	GtkWidget * directory_entry;

	GtkWidget * priority_high_radio;
	GtkWidget * priority_low_radio;

	Group  *group;

	GSList *gslists_of_unowned_articles;
}
SaveAsDialogStruct;

#define IS_ACTIVE(w) gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w))

char*
expand_download_dir (const char * dir, const char * groupname)
{
	char * retval = g_strdup (dir);

	if (is_nonempty_string(groupname))
	{
		if (strstr (dir, "%g") != NULL)
		{
			replace_gstr (&retval, pan_substitute (retval, "%g", groupname));
		}

		if (strstr (dir, "%G") != NULL)
		{
			char tmp[PATH_MAX], *pch;
			g_snprintf (tmp, sizeof(tmp), "%s.", groupname);
			for (pch=tmp; *pch; ++pch)
				if (*pch == '.')
					*pch = G_DIR_SEPARATOR;
			replace_gstr (&retval, pan_substitute (retval, "%G", tmp));
		}
	}

	return retval;
}

static void
save_attachment_as_dialog_response_cb (GtkDialog   * dialog,
                                       int           response,
                                       gpointer      user_data)
{
	SaveAsDialogStruct* save = (SaveAsDialogStruct*)user_data;
	GSList * l;
	GSList * tasks = NULL;
	char * path;
	debug_enter ("save_attachment_as_dialog_clicked_cb");

	if (response == GTK_RESPONSE_DELETE_EVENT ||
	    response == GTK_RESPONSE_CANCEL)
	{
		pan_lock();
		gtk_widget_destroy (GTK_WIDGET(dialog));
		pan_unlock();
		return;
	}

	/**
	***  Get Path
	**/

	path = g_strdup (pan_file_entry_get (save->directory_entry));
	g_strstrip (path);
	if (path!=NULL && *path=='~')
		replace_gstr (&path, g_strconcat (g_get_home_dir(), path+1, NULL));

	/**
	***  Get Body Filename
	**/

	_save_text = IS_ACTIVE(save->save_text_check);

	_save_attachments = IS_ACTIVE(save->save_attachments_check);

	/**
	***  Queue 'em
	**/

	for (l=save->gslists_of_unowned_articles; l!=NULL; l=l->next)
	{
		GSList * m;
		GSList * articles = (GSList*) l->data;
		const Article * article = ARTICLE(articles->data);
		const gchar * subject = article_get_subject (article);
		char * expanded_path = NULL;
		GPtrArray * tmp;
		PanObject * task;

		/* make an array of articles */
		tmp = g_ptr_array_sized_new (64);
		for (m=(GSList*)l->data; m!=NULL; m=m->next)
			g_ptr_array_add (tmp, m->data);
		task_save_weed_duplicates (tmp);
		task = task_save_new_from_articles (subject, (const Article**)tmp->pdata, tmp->len);
		g_ptr_array_free (tmp, TRUE);

		expanded_path = expand_download_dir (path, article->group->name);

		if (_save_attachments)
			task_save_set_attachments (TASK_SAVE(task), expanded_path, NULL);

		if (_save_text)
			task_save_set_bodies (TASK_SAVE(task), expanded_path, NULL);

		tasks = g_slist_prepend (tasks, task);

		g_free (expanded_path);
	}

	if (tasks != NULL)
	{
		tasks = g_slist_reverse (tasks);
		queue_insert_tasks (tasks, _high_priority ? 0 : -1);
	}

	/* cleanup */
	g_free (path);
	pan_lock();
	gtk_widget_destroy (GTK_WIDGET(dialog));
	pan_unlock();
	debug_exit ("save_attachment_as_dialog_clicked_cb");
}

static void
save_toggled_cb (GtkToggleButton    * togglebutton,
                 gpointer              user_data)
{
	SaveAsDialogStruct * save = (SaveAsDialogStruct*) user_data;

	gtk_dialog_set_response_sensitive (GTK_DIALOG(save->dialog),
	                                   GTK_RESPONSE_OK, 
	                                   IS_ACTIVE(save->save_text_check) || IS_ACTIVE(save->save_attachments_check));
}

static void
priority_toggled_cb (GtkToggleButton    * togglebutton,
                     gpointer              user_data)
{
	SaveAsDialogStruct *save = (SaveAsDialogStruct*) user_data;
	gboolean b = gtk_toggle_button_get_active (togglebutton);
	_high_priority = togglebutton==GTK_TOGGLE_BUTTON(save->priority_high_radio) ? b : !b;
}

static void
save_attachment_as_dialog_destroy_cb (GtkDialog * d, gpointer user_data)
{
	GSList * l;
	SaveAsDialogStruct *save = (SaveAsDialogStruct*) user_data;

	/* free the save-as-dialog utility structure */
	for (l=save->gslists_of_unowned_articles; l!=NULL; l=l->next)
		g_slist_free ((GSList*)l->data);

	/* cleanup */
	g_slist_free (save->gslists_of_unowned_articles);
	g_free (save);
}

static void
user_specified_path_changed_cb (GtkEditable   * editable,
                                gpointer        user_data)
{
	replace_gstr (&_path,
	              gtk_editable_get_chars (GTK_EDITABLE(editable), 0, -1));
}

static void
create_save_attachment_as_dialog (Group * group,
                                  GSList * gslists_of_unowned_articles)
{
	GtkWidget * w;
	GtkWidget * l;
	GtkWidget * hbox;
	GtkWidget * vbox;
	GtkWidget * frame;
	GtkWidget * dialog;
	SaveAsDialogStruct * data;
	const char * cpch;

	data = g_new0 (SaveAsDialogStruct, 1);
	data->group = group;
	data->gslists_of_unowned_articles = gslists_of_unowned_articles;

	pan_lock ();

	/* create & parent the dialog */
	dialog = gtk_dialog_new_with_buttons (_("Pan: Save Articles As"),
	                                      GTK_WINDOW(Pan.window),
	                                      GTK_DIALOG_DESTROY_WITH_PARENT,
	                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
	                                      GTK_STOCK_SAVE, GTK_RESPONSE_OK,
	                                      NULL);
	data->dialog = dialog;
	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);

	/**
	***  "Files" Pane
	**/

	pan_hig_frame_new (_("Files"), &frame, &vbox);
	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, GUI_PAD);

	w = gtk_check_button_new_with_mnemonic (_("Save Article Te_xt"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), _save_text);
	data->save_text_check = w;

	w = gtk_check_button_new_with_mnemonic (_("Save Article _Attachments"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), _save_attachments);
	data->save_attachments_check = w;

	hbox = gtk_hbox_new (FALSE, GUI_PAD_SMALL);
	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
	l = gtk_label_new_with_mnemonic (_("_Directory:"));
	gtk_box_pack_start (GTK_BOX(hbox), l, FALSE, FALSE, 0);
	w = pan_file_entry_new (_("Save Files in Directory"));
	gtk_box_pack_start (GTK_BOX(hbox), w, TRUE, TRUE, 0);
	gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
	if (is_nonempty_string(_path))
		cpch = _path;
	else
	if (group && is_nonempty_string (group->download_dir))
		cpch = group->download_dir;
	else
		cpch = download_dir;
	pan_file_entry_set (w, cpch);
	gtk_widget_set_usize (GTK_WIDGET(w), 400, 0);
	data->directory_entry = w;
	w = gtk_button_new_with_mnemonic (_("_Help"));
	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
	g_signal_connect_swapped (w, "clicked", G_CALLBACK (show_group_substitution_help_dialog), dialog);

	/**
	***  "Priority" Pane
	**/

	pan_hig_frame_new (_("Priority"), &frame, &vbox);
	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, GUI_PAD);

	/* front of queue */
	w = gtk_radio_button_new_with_mnemonic (NULL, _("Add to the _top of the Task Manager's List"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), _high_priority);
	data->priority_high_radio = w;

	/* back of queue (default) */
	w = gtk_radio_button_new_with_mnemonic_from_widget (
		GTK_RADIO_BUTTON(w), _("Add to the b_ottom of the Task Manager's List"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), !_high_priority);
	data->priority_low_radio = w;

	/**
	***  Wire it up
	**/

	g_signal_connect (GTK_OBJECT(dialog), "response",
	                  G_CALLBACK(save_attachment_as_dialog_response_cb), data);
	g_signal_connect (GTK_OBJECT(dialog), "destroy",
	                  G_CALLBACK(save_attachment_as_dialog_destroy_cb), data); 
	g_signal_connect (GTK_OBJECT(data->priority_low_radio), "toggled",
	                  G_CALLBACK(priority_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->priority_high_radio), "toggled",
	                  G_CALLBACK(priority_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->save_text_check), "toggled",
	                  G_CALLBACK(save_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->save_attachments_check), "toggled",
	                  G_CALLBACK(save_toggled_cb), data);
	g_signal_connect (pan_file_entry_gtk_entry(data->directory_entry), "changed",
	                  G_CALLBACK(user_specified_path_changed_cb), NULL);
        save_toggled_cb (NULL, data);

	gtk_widget_show_all (dialog);
	pan_unlock ();
}



void
save_attachment_as (Group* group,
		    GSList* gslists_of_unowned_articles)
{
	create_save_attachment_as_dialog (group,
					  gslists_of_unowned_articles);
}

==> pan-0.13.2.92.tar.bz2: pan-0.13.2.92/pan/save-ui.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*********************
**********************  Includes
*********************/

#include <config.h>

#include <string.h>

#include <glib.h>
#include <gtk/gtk.h>

#include <pan/base/base-prefs.h>
#include <pan/base/debug.h>
#include <pan/base/log.h>
#include <pan/base/pan-i18n.h>
#include <pan/base/pan-glib-extensions.h>

#include <pan/globals.h>
#include <pan/gui.h>
#include <pan/prefs.h>
#include <pan/queue.h>
#include <pan/pan-file-entry.h>
#include <pan/task-bodies.h>
#include <pan/task-save.h>
#include <pan/save-ui.h>
#include <pan/text.h>
#include <pan/util.h>

/*********************
**********************  Private Function Prototypes
*********************/

static gchar * _path = NULL;
static gboolean _high_priority = FALSE;
static gboolean _save_attachments = TRUE;
static gboolean _save_text = FALSE;

/*********************
**********************  BEGINNING OF SOURCE
*********************/

typedef struct
{
	GtkWidget * dialog;

	GtkWidget * save_text_check;
	GtkWidget * save_attachments_check;
	GtkWidget * directory_entry;

	GtkWidget * priority_high_radio;
	GtkWidget * priority_low_radio;

	Group  *group;

	GSList *gslists_of_unowned_articles;
}
SaveAsDialogStruct;

#define IS_ACTIVE(w) gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w))

char*
expand_download_dir (const char * dir, const char * groupname)
{
	char * retval = g_strdup (dir);

	if (is_nonempty_string(groupname))
	{
		if (strstr (dir, "%g") != NULL)
		{
			replace_gstr (&retval, pan_substitute (retval, "%g", groupname));
		}

		if (strstr (dir, "%G") != NULL)
		{
			char tmp[PATH_MAX], *pch;
			g_snprintf (tmp, sizeof(tmp), "%s.", groupname);
			for (pch=tmp; *pch; ++pch)
				if (*pch == '.')
					*pch = G_DIR_SEPARATOR;
			replace_gstr (&retval, pan_substitute (retval, "%G", tmp));
		}
	}

	return retval;
}

static void
save_attachment_as_dialog_response_cb (GtkDialog   * dialog,
                                       int           response,
                                       gpointer      user_data)
{
	SaveAsDialogStruct* save = (SaveAsDialogStruct*)user_data;
	GSList * l;
	GSList * tasks = NULL;
	char * path;
	debug_enter ("save_attachment_as_dialog_clicked_cb");

	if (response == GTK_RESPONSE_DELETE_EVENT ||
	    response == GTK_RESPONSE_CANCEL)
	{
		pan_lock();
		gtk_widget_destroy (GTK_WIDGET(dialog));
		pan_unlock();
		return;
	}

	/**
	***  Get Path
	**/

	path = g_strdup (pan_file_entry_get (save->directory_entry));
	g_strstrip (path);
	if (path!=NULL && *path=='~')
		replace_gstr (&path, g_strconcat (g_get_home_dir(), path+1, NULL));

	/**
	***  Get Body Filename
	**/

	_save_text = IS_ACTIVE(save->save_text_check);

	_save_attachments = IS_ACTIVE(save->save_attachments_check);

	/**
	***  Queue 'em
	**/

	for (l=save->gslists_of_unowned_articles; l!=NULL; l=l->next)
	{
		GSList * m;
		GSList * articles = (GSList*) l->data;
		const Article * article = ARTICLE(articles->data);
		char * expanded_path = NULL;
		GPtrArray * tmp;
		PanObject * task;

		/* make an array of articles */
		tmp = g_ptr_array_sized_new (64);
		for (m=(GSList*)l->data; m!=NULL; m=m->next)
			g_ptr_array_add (tmp, m->data);
		task_save_weed_duplicates (tmp);
		task = task_save_new_from_articles ((const Article**)tmp->pdata, tmp->len);
		g_ptr_array_free (tmp, TRUE);

		expanded_path = expand_download_dir (path, article->group->name);

		if (_save_attachments)
			task_save_set_attachments (TASK_SAVE(task), expanded_path, NULL);

		if (_save_text)
			task_save_set_bodies (TASK_SAVE(task), expanded_path, NULL);

		tasks = g_slist_prepend (tasks, task);

		g_free (expanded_path);
	}

	if (tasks != NULL)
	{
		tasks = g_slist_reverse (tasks);
		queue_insert_tasks (tasks, _high_priority ? 0 : -1);
	}

	/* cleanup */
	g_free (path);
	pan_lock();
	gtk_widget_destroy (GTK_WIDGET(dialog));
	pan_unlock();
	debug_exit ("save_attachment_as_dialog_clicked_cb");
}

static void
save_toggled_cb (GtkToggleButton    * togglebutton,
                 gpointer              user_data)
{
	SaveAsDialogStruct * save = (SaveAsDialogStruct*) user_data;

	gtk_dialog_set_response_sensitive (GTK_DIALOG(save->dialog),
	                                   GTK_RESPONSE_OK, 
	                                   IS_ACTIVE(save->save_text_check) || IS_ACTIVE(save->save_attachments_check));
}

static void
priority_toggled_cb (GtkToggleButton    * togglebutton,
                     gpointer              user_data)
{
	SaveAsDialogStruct *save = (SaveAsDialogStruct*) user_data;
	gboolean b = gtk_toggle_button_get_active (togglebutton);
	_high_priority = togglebutton==GTK_TOGGLE_BUTTON(save->priority_high_radio) ? b : !b;
}

static void
save_attachment_as_dialog_destroy_cb (GtkDialog * d, gpointer user_data)
{
	GSList * l;
	SaveAsDialogStruct *save = (SaveAsDialogStruct*) user_data;

	/* free the save-as-dialog utility structure */
	for (l=save->gslists_of_unowned_articles; l!=NULL; l=l->next)
		g_slist_free ((GSList*)l->data);

	/* cleanup */
	g_slist_free (save->gslists_of_unowned_articles);
	g_free (save);
}

static void
user_specified_path_changed_cb (GtkEditable   * editable,
                                gpointer        user_data)
{
	replace_gstr (&_path,
	              gtk_editable_get_chars (GTK_EDITABLE(editable), 0, -1));
}

static void
create_save_attachment_as_dialog (Group * group,
                                  GSList * gslists_of_unowned_articles)
{
	GtkWidget * w;
	GtkWidget * l;
	GtkWidget * hbox;
	GtkWidget * vbox;
	GtkWidget * frame;
	GtkWidget * dialog;
	SaveAsDialogStruct * data;
	const char * cpch;

	data = g_new0 (SaveAsDialogStruct, 1);
	data->group = group;
	data->gslists_of_unowned_articles = gslists_of_unowned_articles;

	pan_lock ();

	/* create & parent the dialog */
	dialog = gtk_dialog_new_with_buttons (_("Pan: Save Articles As"),
	                                      GTK_WINDOW(Pan.window),
	                                      GTK_DIALOG_DESTROY_WITH_PARENT,
	                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
	                                      GTK_STOCK_SAVE, GTK_RESPONSE_OK,
	                                      NULL);
	data->dialog = dialog;
	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);

	/**
	***  "Files" Pane
	**/

	pan_hig_frame_new (_("Files"), &frame, &vbox);
	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, GUI_PAD);

	w = gtk_check_button_new_with_mnemonic (_("Save Article Te_xt"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), _save_text);
	data->save_text_check = w;

	w = gtk_check_button_new_with_mnemonic (_("Save Article _Attachments"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), _save_attachments);
	data->save_attachments_check = w;

	hbox = gtk_hbox_new (FALSE, GUI_PAD_SMALL);
	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
	l = gtk_label_new_with_mnemonic (_("_Directory:"));
	gtk_box_pack_start (GTK_BOX(hbox), l, FALSE, FALSE, 0);
	w = pan_file_entry_new (_("Save Files in Directory"));
	gtk_box_pack_start (GTK_BOX(hbox), w, TRUE, TRUE, 0);
	gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
	if (is_nonempty_string(_path))
		cpch = _path;
	else
	if (group && is_nonempty_string (group->download_dir))
		cpch = group->download_dir;
	else
		cpch = download_dir;
	pan_file_entry_set (w, cpch);
	gtk_widget_set_usize (GTK_WIDGET(w), 400, 0);
	data->directory_entry = w;
	w = gtk_button_new_with_mnemonic (_("_Help"));
	gtk_box_pack_start (GTK_BOX(hbox), w, FALSE, FALSE, 0);
	g_signal_connect_swapped (w, "clicked", G_CALLBACK (show_group_substitution_help_dialog), dialog);

	/**
	***  "Priority" Pane
	**/

	pan_hig_frame_new (_("Priority"), &frame, &vbox);
	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, GUI_PAD);

	/* front of queue */
	w = gtk_radio_button_new_with_mnemonic (NULL, _("Add to the _top of the Task Manager's List"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), _high_priority);
	data->priority_high_radio = w;

	/* back of queue (default) */
	w = gtk_radio_button_new_with_mnemonic_from_widget (
		GTK_RADIO_BUTTON(w), _("Add to the b_ottom of the Task Manager's List"));
	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), !_high_priority);
	data->priority_low_radio = w;

	/**
	***  Wire it up
	**/

	g_signal_connect (GTK_OBJECT(dialog), "response",
	                  G_CALLBACK(save_attachment_as_dialog_response_cb), data);
	g_signal_connect (GTK_OBJECT(dialog), "destroy",
	                  G_CALLBACK(save_attachment_as_dialog_destroy_cb), data); 
	g_signal_connect (GTK_OBJECT(data->priority_low_radio), "toggled",
	                  G_CALLBACK(priority_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->priority_high_radio), "toggled",
	                  G_CALLBACK(priority_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->save_text_check), "toggled",
	                  G_CALLBACK(save_toggled_cb), data);
	g_signal_connect (GTK_OBJECT(data->save_attachments_check), "toggled",
	                  G_CALLBACK(save_toggled_cb), data);
	g_signal_connect (pan_file_entry_gtk_entry(data->directory_entry), "changed",
	                  G_CALLBACK(user_specified_path_changed_cb), NULL);
        save_toggled_cb (NULL, data);

	gtk_widget_show_all (dialog);
	pan_unlock ();
}



void
save_attachment_as (Group* group,
		    GSList* gslists_of_unowned_articles)
{
	create_save_attachment_as_dialog (group,
					  gslists_of_unowned_articles);
}
